import { BasicEvent } from "@skeldjs/events";
import { CheckProtectMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player (i.e. a guardian angel) is attempting to protect another
 * player, and is requesting the host to verify the attempt and actually protect
 * the player. Only admitted if the client is the host.
 *
 * This event is useful if you want to prevent a protect from actually happening,
 * before it happens. Therefore this event doesn't guarantee that the target is
 * actually dead, see {@link PlayerProtectEvent} to listen for that.
 */
export declare class PlayerCheckProtectEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: CheckProtectMessage | undefined;
    /**
     * The other player that the player is attempting to protect.
     */
    readonly target: PlayerData<RoomType>;
    /**
     * Whether or not this protect would normally be considered valid and thus
     * the player be protected.
     */
    readonly isValid: boolean;
    static eventName: "player.checkprotect";
    eventName: "player.checkprotect";
    private _alteredPlayer;
    private _alteredTarget;
    private _alteredIsValid;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: CheckProtectMessage | undefined, 
    /**
     * The other player that the player is attempting to protect.
     */
    target: PlayerData<RoomType>, 
    /**
     * Whether or not this protect would normally be considered valid and thus
     * the player be protected.
     */
    isValid: boolean);
    /**
     * The player that will protect the target instead, if altered.
     */
    get alteredPlayer(): PlayerData<RoomType>;
    /**
     * Change the player that will actually protect the target.
     */
    setPlayer(player: PlayerData<RoomType>): void;
    /**
     * The player that will protected instead, if altered.
     */
    get alteredTarget(): PlayerData<RoomType>;
    /**
     * Change the player that will actually be protected.
     * @param target The player to protect.
     */
    setTarget(target: PlayerData<RoomType>): void;
    /**
     * Whether or not this protect will be considered valid instead, if altered.
     */
    get alteredIsValid(): boolean;
    /**
     * Change whether this protect should be consider valid. If valid, ths player
     * will indeed be protected.
     * @param isValid Whether or not this protect should be considered valid.
     */
    setValid(isValid: boolean): void;
}
//# sourceMappingURL=CheckProtect.d.ts.map