"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HudOverrideSystem = void 0;
const SystemStatus_1 = require("./SystemStatus");
const events_1 = require("../events");
/**
 * Represents a system responsible for handling communication sabotages on The Skeld and Polus.
 *
 * See {@link HudOverrideSystemEvents} for events to listen to.
 */
class HudOverrideSystem extends SystemStatus_1.SystemStatus {
    constructor(ship, systemType, data) {
        super(ship, systemType, data);
        this._sabotaged = false;
    }
    /**
     * Whether or not communications is sabotaged.
     */
    get sabotaged() {
        return this._sabotaged;
    }
    patch(data) {
        this._sabotaged = data.sabotaged;
    }
    /* eslint-disable-next-line @typescript-eslint/no-unused-vars */
    Deserialize(reader, spawn) {
        const before = this.sabotaged;
        this._sabotaged = reader.bool();
        if (!before && this._sabotaged)
            this.emit(new events_1.SystemSabotageEvent(this.room, this, undefined, undefined)).then(ev => {
                if (ev.reverted) {
                    this.repair();
                }
            });
        if (before && !this._sabotaged)
            this.emit(new events_1.SystemRepairEvent(this.room, this, undefined, undefined)).then(ev => {
                if (ev.reverted) {
                    this.sabotage();
                }
            });
    }
    /* eslint-disable-next-line @typescript-eslint/no-unused-vars */
    Serialize(writer, spawn) {
        writer.bool(this.sabotaged);
    }
    async HandleSabotage(player, rpc) {
        this._sabotaged = true;
        this.dirty = true;
        const ev = await this.emit(new events_1.SystemSabotageEvent(this.room, this, rpc, player));
        if (ev.reverted) {
            this._sabotaged = false;
        }
    }
    async _repair(player, rpc) {
        this._sabotaged = false;
        this.dirty = true;
        const ev = await this.emit(new events_1.SystemRepairEvent(this.room, this, rpc, player));
        if (ev.reverted) {
            this._sabotaged = true;
        }
    }
    async repair() {
        if (this.ship.canBeManaged()) {
            await this._repair(this.room.myPlayer, undefined);
        }
        else {
            await this._sendRepair(0);
        }
    }
    async HandleRepair(player, amount, rpc) {
        if (amount === 0) {
            await this._repair(player, rpc);
        }
    }
}
exports.HudOverrideSystem = HudOverrideSystem;
//# sourceMappingURL=HudOverrideSystem.js.map